@@ -691,7 +691,14 @@ def test_reference():
         r = fsa.Reference(obj="hello", fun=gen_data)
         assert False, "should have raised an exception"
     except Exception as e:
-        assert "reference cannot have both obj and fun" in str(e)
+        assert "reference cannot set both obj and fun" in str(e)
+    try:
+        r = fsa.Reference(set_name="add")
+        r.add()
+        assert False, "missing parameter in previous call"
+    except Exception as e:
+        assert "reference must set either obj or fun" in str(e)
+
 
 def test_www_authenticate(client):
     push_auth(app._fsa, "param")
@@ -1216,7 +1223,11 @@ def test_warnings_and_errors():
     @app.cast("foo")
     def cast_foo(s: str):
         return s
-    app.cast("foo", cast_foo)
+    assert app._fsa._casts["foo"] == cast_foo
+    app.cast("foo", lambda x: cast_foo(x))
+    assert app._fsa._casts["foo"] != cast_foo
+    s = "Hello World!"
+    assert app._fsa._casts["foo"](s) == cast_foo(s)
     # type errors
     try:
         app = af.create_app(FSA_CAST="not a dict")
